@@ -127,6 +127,8 @@ applet_fill (PanelApplet *applet)
     GtkTooltips *tooltips;
     int err;
 
+    gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-cdplayer-icon.png");
+    
     cd = g_new0(CDPlayerData, 1);
     cd->panel.applet = GTK_WIDGET (applet);
     
@@ -219,12 +221,14 @@ cdplayer_destroy(GtkWidget * widget, gpointer data)
         g_object_unref (tooltips);
         g_object_set_data (G_OBJECT (cd->panel.applet), "tooltips", NULL);
     }
-    
+   
     if (cd->time_description)
-        g_free(cd->time_description); 
+        g_free(cd->time_description);
     if (cd->track_description)
         g_free(cd->track_description);
+
     g_free (cd->devpath);
+ 
     cd->devpath = NULL;
     g_free(cd);
 }
@@ -265,7 +269,7 @@ static void
 response_cb (GtkDialog *dialog, gint id, gpointer data)
 {
     if(id == GTK_RESPONSE_HELP){
-         phelp_cb (dialog,data);
+         phelp_cb (NULL,data);
 	 return;
     }
     gtk_widget_destroy (GTK_WIDGET (dialog));
@@ -461,7 +465,6 @@ about_cb(GtkWidget *w, gpointer data)
     	gdk_pixbuf_unref (pixbuf);
 
     gtk_window_set_wmclass (GTK_WINDOW (about), "cd player", "CD Player");
-    gnome_window_icon_set_from_file (GTK_WINDOW (about), GNOME_ICONDIR"/gnome-cdplayer-icon.png");	
     g_signal_connect (G_OBJECT(about), "destroy",
                       G_CALLBACK(gtk_widget_destroyed), &about);
     gtk_widget_show (about);
@@ -575,19 +578,22 @@ setup_box(CDPlayerData* cd)
     gtk_widget_show_all(cd->panel.frame);
 }
 
+/* This is a hack around the fact that gtk+ doesn't
+ * propogate button presses on button2/3.
+ */
 static gboolean 
-button_press_hack (GtkWidget *w, GdkEventButton *event, gpointer data)
+button_press_hack (GtkWidget      *widget,
+		   GdkEventButton *event,
+		   GtkWidget      *applet)
 {
-    PanelApplet *applet = PANEL_APPLET (data);
-    /* Pass the right click to the PanelApplet */
-    if (event->button == 3) {
-    	GTK_WIDGET_CLASS (PANEL_APPLET_GET_CLASS (applet))->
-			  button_press_event (data, event);
+    if (event->button == 3 || event->button == 2) {
+	event->window = applet->window;
+	gtk_main_do_event ((GdkEvent *) event);
+
 	return TRUE;
     }
     
     return FALSE;
-    
 }
 
 static GtkWidget *
@@ -605,12 +611,13 @@ control_button_factory(gchar * pixmap_data[], GCallback func, CDPlayerData * cd)
     	g_object_unref (pixbuf);
     gtk_widget_show(image);
     gtk_container_add(GTK_CONTAINER(w), image);
-    /* This is a hack to get the right click menu working with buttons
-    ** Should be removed when libpanelapplet is fixed */
-    g_signal_connect (G_OBJECT (w), "button_press_event",
-    		      G_CALLBACK (button_press_hack), cd->panel.applet);
-    g_signal_connect(G_OBJECT(w), "clicked",
-                     G_CALLBACK(func), cd);
+
+    g_signal_connect (w, "button_press_event",
+    		      G_CALLBACK (button_press_hack),
+		      cd->panel.applet);
+    g_signal_connect (w, "clicked",
+		      G_CALLBACK(func), cd);
+
     gtk_widget_show(w);
     gtk_widget_ref(w);
     return(w);
@@ -739,6 +746,8 @@ cd_panel_update(GtkWidget * cdplayer, CDPlayerData * cd)
             _("Track number"), cd->track_description);
         g_free (cd->time_description);
         g_free (cd->track_description);
+        cd->time_description = NULL;
+        cd->track_description = NULL;
     }
     else
     {
@@ -913,7 +922,7 @@ static void
 phelp_cb (GtkWidget *w, gpointer data)
 {
     GError *error = NULL;
-    gnome_help_display ("cdplayer", "cdplayer-usage", &error);
+    gnome_help_display ("cdplayer", "cdplayer_applet_prefs", &error);
     
     if (error) {
         g_warning ("help error: %s\n", error->message);
